@@ -11,8 +11,8 @@ const (
 	TrustedCABundleHashName     = "logging.openshift.io/hash"
 	KibanaTrustedCAName         = "kibana-trusted-ca-bundle"
 	SecretHashPrefix            = "logging.openshift.io/"
-	ElasticsearchDefaultImage   = "quay.io/openshift/origin-logging-elasticsearch6"
-	ProxyDefaultImage           = "quay.io/openshift/origin-elasticsearch-proxy:latest"
+	ElasticsearchDefaultImage   = "quay.io/openshift-logging/elasticsearch6:6.8.1"
+	ProxyDefaultImage           = "quay.io/openshift-logging/elasticsearch-proxy:1.0"
 	TheoreticalShardMaxSizeInMB = 40960
 
 	// OcpTemplatePrefix is the prefix all operator generated templates
